package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````>18``#0```"0@0````0`!30`(``)
M`"@`&P`:``$``'"X?```N'P``+A\```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````#$?```Q'P```4`````$```
M`0```,!]``#`C0``P(T``(@"``"<`@``!@`````0```"````R'T``,B-``#(
MC0``"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DP'T`
M`,"-``#`C0``0`(``$`"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`I&T_J!"^9$NX+:I\9>IEE%6BB;X$
M````$`````$```!'3E4```````,````"`````````!$```!*````"`````@`
M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"$H```!+````3@``
M`%(```!3````7````%T```!>`````````&````!A````8@```&,```!D````
M9P```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+(!BV^93\.;:PE#UF>O
MS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)N^VE<;X*<""FL:GE"CX/M)````
M``````````````````````"H$0````````,`"P```````)`````````#`!8`
M<`(`````````````$@```%X"`````````````!(```#/`@`````````````2
M````C@(`````````````(@```/4"`````````````!$```""`P``````````
M```2````$```````````````(````/\!`````````````!(```"Z`@``````
M```````2````XP$`````````````$@```.D``````````````!(````1`P``
M```````````1````R`(`````````````$@```$T!`````````````!(```#Y
M`0`````````````2````AP``````````````$@```*0"`````````````!(`
M``#D```````````````2````O0$`````````````$@```)4!````````````
M`!(```#_`@`````````````2````W`$`````````````$@```#H"````````
M`````!(````_`0`````````````2````Q@``````````````$0````T!````
M`````````!(```!C```````````````6````,0(`````````````$@```(`"
M`````````````!$```![`0`````````````2````JP$`````````````$@``
M`&@!`````````````!(```"R`@`````````````2````S0$`````````````
M$@```'0!`````````````!(````*`@`````````````2````&P$`````````
M````$@````$``````````````"`````9`@`````````````2````I@$`````
M````````$@```/(!`````````````!(```"&`0`````````````1````5```
M````````````$@```)T"`````````````!(```"6```````````````2````
MU@(`````````````$@```$("`````````````!(```"B```````````````2
M````-`$`````````````$@````0"`````````````!(```"K`@``````````
M```2````^@``````````````$@```$8``````````````!(```#N````````
M```````2````70$`````````````$@```%`"`````````````!(```#3````
M```````````2````AP(`````````````$@```,$"`````````````!(```#K
M`0`````````````2````(`(`````````````$@```'8``````````````!(`
M``#4`0`````````````2````LP$`````````````$@```+<`````````````
M`!(````K`0`````````````2````+```````````````(````/<"````````
M`````!$```#M`@`````````````2````YP(`````````````$@```,0!````
M`````````!(```"?`P``7)`````````0`!<`BP,``'TM``#,````$@`-`,,#
M``#-)@``T`0``!(`#0!K`@``H10``-@!```2``T`40,``%$=```$````$@`-
M`&(#``!(D````````!``%P!/!```51T``+`!```2``T`C00``)TK``#@`0``
M$@`-`#L$``!(D````````!``%P"J`P``!1\``"0````2``T`T`,``/DX``#D
M````$@`-`.@#``#`.@``!````!$`#P`7!```7)`````````0`!<`'`0``%R0
M````````$``7`$<$``!5'```/````!(`#0!<!```!28``,@````2``T`;@0`
M`.TC``!L````$@`-`'P$``!9)```5````!(`#0#;`P```)`````````0`!8`
MMP,``"D?```<`0``$@`-`)<#``!(D````````!``%@`-!```1)````0````1
M`!8`X0,``'D6````````$@`-`(0$``!Y.```@````!(`#0#=`P```)``````
M```@`!8`<`,``.DE```<````$@`-`)X#``!<D````````!``%P#W`P``D1P`
M`,`````2``T`,00``-TY``#*````$@`-`"0$``!%(```J`,``!(`#0``7U]G
M;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L
M7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P
M97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`
M<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L
M7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!03%]M96UO<GE?=W)A<`!?7W-T
M86-K7V-H:U]F86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L
M;W-E9&ER`&]P96XV-`!S=')R8VAR`'5N;&EN:P!M96UM;W9E`'-T<G1O:P!S
M=')L96X`<FUD:7(`<F5A9`!M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`
M7U]L<W1A=#8T7W1I;64V-`!R96%D;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C
M:&L`7U]F<')I;G1F7V-H:P!?7VQI8F-?<W1A<G1?;6%I;@!?7W-T870V-%]T
M:6UE-C0`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA;&EZ90!S=')C:'(`;65M
M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M
M<`!?7V5R<FYO7VQO8V%T:6]N`&%B;W)T`'-T<FYC;7``7U]E;G9I<F]N`%]?
M<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N
M-2XS.`!L:6)C+G-O+C8`;&0M;&EN=7@M87)M:&8N<V\N,P!P87)?8W5R<F5N
M=%]E>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M
M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A=&%?
M<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`&UY
M7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?96YV`'-H85]F:6YA;`!?
M7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB
M<&%T:`!P87)?96YV7V-L96%N`'!A<E]D:64`<VAA7VEN:70`6%-?26YT97)N
M86QS7U!!4E]"3T]4`$=,24)#7S(N-`!'3$E"0U\R+C,T``````````(``@`#
M``,``P`#``$``P`#``,``P`$``,``0`#``$``P`!``,``P`#``,``P`!``$`
M`0`!``,``P`!``,``0`#``,``P`#``$``0`#``,``P`!``$``P`!``,``P`!
M``$``P`#``$``0`!``$``P`!``,``P`#``(``0`#``,``0`!``$``P`#``,`
M`P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$`/0,``!`````@````%&EI#0``!`"C!```
M``````$``@`S`P``$``````````4:6D-```#`*,$```0````M)&6!@```@"M
M!````````,"-```7````Q(T``!<```#PCP``%P````20```7````%)```!<`
M```8D```%P```""0```7````))```!<````HD```%P```"R0```7````,)``
M`!<````XD```%P```#R0```7````1)```!<```#(CP``%08``,R/```5"0``
MT(\``!4.``#4CP``%1```-B/```5&P``W(\``!,=``#@CP``%1\``.2/```5
M*```Z(\``!4L``#LCP``%38``/2/```50```^(\``!5%``#\CP``%48``-R.
M```6`P``X(X``!8$``#DC@``%@4``.B.```6!@``[(X``!8(``#PC@``%@H`
M`/2.```6"P``^(X``!8,``#\C@``%@T```"/```6#P``!(\``!81```(CP``
M%A(```R/```6$P``$(\``!84```4CP``%A4``!B/```6%@``'(\``!87```@
MCP``%A@``"2/```6&0``*(\``!8:```LCP``%AP``#"/```6'@``-(\``!8@
M```XCP``%B$``#R/```6(@``0(\``!8C``!$CP``%B0``$B/```6)0``3(\`
M`!8F``!0CP``%B<``%2/```6*```6(\``!8I``!<CP``%BH``&"/```6*P``
M9(\``!8M``!HCP``%BX``&R/```6+P``<(\``!8P``!TCP``%C$``'B/```6
M,@``?(\``!8S``"`CP``%C0``(2/```6-0``B(\``!8W``",CP``%C@``)"/
M```6.0``E(\``!8Z``"8CP``%CL``)R/```6/```H(\``!8]``"DCP``%CX`
M`*B/```6/P``K(\``!9!``"PCP``%D(``+2/```60P``N(\``!9$``"\CP``
M%D<``,"/```62```Q(\``!9)```(0"WI/@$`ZPB`O>@$X"WE!."?Y0[@C^`(
M\+[E#'T```#&C^('RHSB#/V\Y0#&C^('RHSB!/V\Y0#&C^('RHSB_/R\Y0#&
MC^('RHSB]/R\Y0#&C^('RHSB[/R\Y0#&C^('RHSBY/R\Y0#&C^('RHSBW/R\
MY0#&C^('RHSBU/R\Y7A'_><`QH_B!\J,XLC\O.4`QH_B!\J,XL#\O.4`QH_B
M!\J,XKC\O.4`QH_B!\J,XK#\O.4`QH_B!\J,XJC\O.4`QH_B!\J,XJ#\O.5X
M1_WG`,:/X@?*C.*4_+SE`,:/X@?*C.*,_+SE>$?]YP#&C^('RHSB@/R\Y0#&
MC^('RHSB>/R\Y0#&C^('RHSB</R\Y0#&C^('RHSB:/R\Y0#&C^('RHSB8/R\
MY0#&C^('RHSB6/R\Y0#&C^('RHSB4/R\Y0#&C^('RHSB2/R\Y0#&C^('RHSB
M0/R\Y0#&C^('RHSB./R\Y0#&C^('RHSB,/R\Y0#&C^('RHSB*/R\Y0#&C^('
MRHSB(/R\Y0#&C^('RHSB&/R\Y0#&C^('RHSB$/R\Y0#&C^('RHSB"/R\Y0#&
MC^('RHSB`/R\Y0#&C^('RHSB^/N\Y0#&C^('RHSB\/N\Y0#&C^('RHSBZ/N\
MY0#&C^('RHSBX/N\Y0#&C^('RHSBV/N\Y0#&C^('RHSBT/N\Y0#&C^('RHSB
MR/N\Y7A'_><`QH_B!\J,XKS[O.4`QH_B!\J,XK3[O.4`QH_B!\J,XJS[O.4`
MQH_B!\J,XJ3[O.4`QH_B!\J,XIS[O.4`QH_B!\J,XI3[O.4`QH_B!\J,XHS[
MO.4`QH_B!\J,XH3[O.4`QH_B!\J,XGS[O.4`QH_B!\J,XG3[O.4`QH_B!\J,
MXFS[O.4`QH_B!\J,XF3[O.4`QH_B!\J,XES[O.4`QH_B!\J,XE3[O.4`QH_B
M!\J,XDS[O.4`QH_B!\J,XD3[O.4`QH_B!\J,XCS[O.4`QH_B!\J,XC3[O.4`
MQH_B!\J,XBS[O.4`````<+5/](!<K>L,#,SXR`]>38JP7DM]1%Y,S>D&$`:I
M!9('J`6J?$3K6!MH"9-/\``#__=,[U=*6$NB6`.2$4;C6`23&$8"\.#Z5$OC
M6!UX`"UCT!WN<"]*2P>8>T0;:,4<!#"P\8!/TEB2^-8S0_`#`X+XUC-TTH``
M__?L[DA)24H#1GE$!IQZ1`EH4&`@:)E@14D'FGE$V6!$20$J&&!Y1%E@9=TA
M'03K@@X#\0P,4?@$2TSX!$^.1?G1T1P\3``@`)`J1GQ$0_@A`#I)X&AY1/_W
M0.\`*#'0-TT(KGU$Z&C_]YKN!$8U2#%&>$0`\/+X0+,S2WM$V&C_]V;N__<>
M[S!*(DMZ1--8&F@)FUI`3_```S+1($8*L'"]__>0[BI*>D308#"S__=$[A9+
M'>YP+WM$&VC36(/XOE:,Y^!H__=&[\GGJ&@0L0'PR/O1YQ](,49X1`#POOBH
M8``HR=#SYQM+'$AX1.-8`Y,91O_WS.X$(:/G`2#_]Y[N__<T[@"_WGH```AZ
M```8>@````$```AZ```<`0``)`$```@!```>>P``(GL``$`I```R*0``Y'H`
M`&L&``#,>@``BB8``+1Z```H>0``B'H``+XE```8`0``K"<``$_P``M/\``.
M`KQJ1@2T`;3?^!B@!:.:1$_P``,(M`1(6O@``/_WFNW_]_#N+'@``"`!```4
M,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$<___J%'@``!0!```&2`=+!TIX1'M$
M>D2#0@/0!4O36`.Q&$=P1P"_;GD``&QY``#R=P``_`````A("4MX1`E*>T0;
M&GI$V0\!ZZ,!21`#T`5+TU@#L1A'<$<`OT1Y``!`>0``Q'<``"@!```(M0I+
M"DI[1'I$&WAKN0E+TU@CL0A+>T08:/_W4.W_][__!DL!(GM$&G`(O0YY``"4
M=P``^````+IX``#N>```Q.<`ORWI^$-/](!<K>L,#,SXX`\?2X!&>T0`*#;0
M'DJ;6-/X`)"Y\0`/,=`%>`]&`"T8OSTM%+\!)0`E$]'9^`!`;+%.1BI&048@
M1O_W7.X0N6-=/2L0T%;X!$\`+/+1($:]Z/B#!485^`$_`"L8OSTK^=&EZP@%
MX>>FZPD&`34L1+80/F`@1KWH^(,$1N?G3$;EYT1W```L`0``$+5/](!<K>L,
M#,SX@`\72IZP%TMI1GI$!$;36!MH'9-/\``#__<$[J"Y!)L#]'!#L_4@3QB_
ML_6`3PW0#4H,2WI$TU@::!V;6D!/\``#"]$>L!"]`"#QYP(A($;_]]SML/J`
M\$`)Z>?_]P;MJG8````!``"`=@``\+5/](!<K>L,#,SX:`\V2J&P-DMZ1--8
M&V@?DT_P``,0L0-X!$9;N3%*,$MZ1--8&F@?FUI`3_```U/1(;#PO?_W'.T%
M1@`H[M`H1O_WP.T`*#;0PWP`\1,&+BL"T7-X`"ORT,-\+BLRT"!&__<V[0=&
M,$;_]S+M.$0",/_W"NT<2T_P_S(!(7M$`98`E`9&__="[0*I,$;_]U3L`3`P
M1@70!IL#]'!#L_6`3Q?0__>V[#!&__=X["A&__>*[0`HR-$H1O_WHNT@1O_W
M>NRKYW-X+BO)T;-X`"NVT,7G__>/_^;G__>,[#1V`````0``''8``$0B```M
MZ?!'3_2`7*WK#`S,^-@/5TJ"L%=+#$9Z1`5&W_A8@=-8^$0;:`&33_```PMX
M/2L(OP$T($;_]];L:48&1BA&__?:_H%&`"A4T/_WS.R&0D?92DL`GUCX`X"_
M`"MX`"L8OSTK%+\!(P`C!]`K1A/X`2\`*AB_/2KYT5L;L!S8^`!@&$3_]XKL
M\%'HL=CX`#`H1ME9$/@!.PMP/2L8OP`K"=!*'!#X`3L11@+X`3L]*QB_`"OV
MT0I&/2,+<!3X`3L"^`$_`"OYT2U**DMZ1--8&F@!FUI`3_```T;1`K"]Z/"'
M"?'_.13X`3L)^`$_`"OYT>GG(4M8^`.`V/@`<#MH@[,[1E/X!"])1@GQ`0D`
M*OC1`S&)`!M*>D03:+NY"$8!(Q-@__<Z[()&`"C,T#E&3^J)!SI&__>TZ\CX
M`*#-^`"0"?$!"0`C2O@I,(;G.$;_]^[K@D;(^````"BTT$_JB0?LYYE&""'5
MY__WSNL`OSAU`````0``+G4``"P!``"$=```M'4``"WI\$%/](!<K>L,#,SX
M``!,^"`,#T8L22Q+K?6`77E$@K`&1@WU@%`$,`WQ!`C+6$#V_W)!1AMH`V!/
M\``#)$AX1/_WQ.L$'@?=`JUC'@7K`PP<^`0LZKG;N1E+'>YP#SI&,49[1!MH
MP%C_]ZKK&4H-]8!1%4L$,7I$TU@::`MH6D!/\``#&-$-]8!=`K"]Z/"!'$8B
M1B\A0$;_]SSL`"C;T`A('>YP7R-&0D9X1`!H,48H6/_W4NS9Y__W8NL`OW!T
M```H=```JG,````!```4(```4',``#"U3_2`7*WK#`S,^.`/$TH=[G!/#TF%
ML!%(>D1Y1`EH$$L`)7M$$EA@6`])`Y)Y1/_WU.L(20U+>40):`Q*>T1Z1&!8
M"TD!E7E$`)/_]_#K!;`PO>!S``#$<P``UG(```0!```08```7A\``%(B``!]
M#P``8!\```I*@K`*21WN<,]Z1`9("4MX1`!H4EA[1`=)7/@``'E$`9("L/_W
MG+MT<P``;G(```0!``"F7P``]AX``'"U3_2`7*WK#`S,^```K/6`7,SX``!,
M^"@,)$JM]0!=(TN&L'I$#?4`410Q`ZP-]8!6TU@0-AMH"V!/\``#__<\ZQQ*
M`2$<2WI$S>D``GM$($9!\@$"__=:ZR!&3_2`4C%&__?NZ@0>N+\`)0K;8!S_
M]PKK!48HL2)&,4;_]Y3J`",K50U*#?4`40E+%#%Z1--8&F@+:%I`3_```P31
M*$8-]0!=!K!PO?_WI.H8<@````$``-`>``"^'@``KG$``/_WGK\MZ?!/3_2`
M7*WK#`S,^```3/BP#%I*K?6$75I+@[!Z1`9&64@-]815#?$0"`0UTU@,1GA$
M048;:"M@3_```__W[_PO(05&,$;_]^SJP+%/2#%&>$3_]^C],$9-2@WUA%%(
M2P0Q>D336!IH"VA:0$_P``-`\(.`#?6$70.PO>CPCR!&__=0ZD-)>43_]RCK
M!$8`*-S0(W@-\8@*W_C\D*KQ!`?Y1``K2-`EL2%&*$;_]^[IN+,@1O_WJNI#
M'B-$@T:<0CZ_(Q@`(6`<`],*X)A"&7`#T!/X`2TO*OC0($;_]Y;J@T8P1O_W
MDNI81`$PL/6`7ZS2*4@!(4M&3_2`4GA$`)3-Z0$&.$;_]Y[J048X1O_WL.DP
MN5KX:#P#]'!#L_4`3Q?0'DD`('E$__?8Z@1&`"B,T"-X`"NVT=6Q*W@N*P30
M&$Q/\`$+?$3+YVMX`"OHT/;G`2$X1O_WNNH`*.'1$4@Y1GA$__=?_3A&__?:
MZ7/G#DQ/\`$+?$2SY__WV.E:<0````$``"H>```6'@``%'$``/`=``#:'0``
MAAT``%`=```0'0``!!T``.`<```0M4_T@%RMZPP,S/CX#R\A!$;_]YCJ`+%$
M'"!&O>@00/_WIKGPM4_T@%RMZPP,S/@``$SX(`P[2JWU@%TZ2X.P>D0-]8!1
M!#'36!MH"V!/\``#`"@\T`-X!48`*SC0__?^Z4(<!$:R]8!?1]@!KRE&.$;_
M]V#I8QX[1)]""](X&0WQ!0(`(0+@D$(!<`/0$/@!/2\K^-`O(3A&__=4ZGBS
MN$*$OP`C`W`X1O_W9.D?2@WU@%$<2P0Q>D336!IH"VA:0$_P``,KT0WU@%T#
ML/"]%TH-]8!1%$L$,7I$TU@::`MH6D!/\``#&M$22'A$#?6`70.PO>CP0/_W
M.KD`(-;G#4H-]8!1"$L$,7I$TU@::`MH6D!/\``#`M$(2'A$YN?_]R[IB&\`
M```!```0;P``[FX``+P;``"^;@``C!L``'"U3_2`7*WK#`S,^.@/S$J"L,Q+
M;$9Z1,M.S$U^1--8?40;:`&33_```R%&,$;_]W_[L+'&2P"8ZU@9:`'K@`-:
M:$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W:?L`*.C1O$Y^1"%&,$;_]V'[
ML+&W2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W2_L`
M*.C1KDY^1"%&,$;_]T/[L+&H2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X
M!"L`*OK1(48P1O_W+?L`*.C1H$Y^1"%&,$;_]R7[L+&92P"8ZU@9:`'K@`-:
M:$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W#_L`*.C1DDY^1"%&,$;_]P?[
ML+&*2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W\?H`
M*.C1A$Y^1"%&,$;_]^GZL+%[2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X
M!"L`*OK1(48P1O_WT_H`*.C1=DY^1"%&,$;_]\OZL+%L2P"8ZU@9:`'K@`-:
M:$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_WM?H`*.C1:$Y^1"%&,$;_]ZWZ
ML+%=2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_WE_H`
M*.C16DY^1"%&,$;_]X_ZL+%.2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X
M!"L`*OK1(48P1O_W>?H`*.C13$Y^1"%&,$;_]W'ZL+$_2P"8ZU@9:`'K@`-:
M:$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W6_H`*.C1/DY^1"%&,$;_]U/Z
ML+$P2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W/?H`
M*.C1,$@A1GA$__<V^@%&&+$M2'A$__<T^RQ((49X1/_W*_H!1ABQ*DAX1/_W
M*?LI2"%&>$3_]R#Z`4:PL29(>$3_]Q[[)4H12WI$TU@::`&;6D!/\``#%=$A
M22)(>41X1`*PO>AP0/_W"[L?2"%&>$3_]P+Z`48`*.30'$AX1/_W__K?Y_[W
M@.]R;@````$``'P;``!H;@``+`$``$`;```,&P``W!H``*@:``!\&@``W!D`
M`!`:``#@&0``L!D``/@8``!"&0``'AD``$`9``!(&0``2AD``'88``"(:P``
M1!D``*H8```>&0``J!@```"U3_2`7*WK#`S,^/`/$TJ#L!-+:49Z1!)(>$33
M6!MH`9-/\``#__>O^4"Q`'@`*!B_,"@,OP$@`""`\`$`"DH'2WI$TU@::`&;
M6D!/\``#`M$#L%WX!/O^]Q[ORFH````!```:&```GFH```^T3_2`7`"UK>L,
M#,SX\`_?^##`@[`,2@2K_$0+20Q(>41<^`(@$F@!DD_P``)3^`0K`),(6`$A
M`&C^]TCO_R#^]USO6FH````!``!4:@``$`$``"WI\$=/\``,3_2`/JWK#`RL
MZPX.K/6`7,SX``#T1?G13O@X#*WU@#V&L#Y,`B$-]8`U?$04-0"1`"([20`C
M@$9A6`EH*6!/\``!_O?X[@$X8?$`!_H7@.H"`YL:F[)30)L:8NL"`L8:9^L"
M!P`O2]M/\`@)P/(!"0.M`"$R1CM&0$8`D?[WVNZQ\?\_"+^P\?\_0=!*1BE&
M0$;^]U[N0QPVT`<H)MD(."P8(]+?^'R@^D0"X`$\K$(<TP@B448@1O[W=NX`
M*/719!N@&4?KY'$72@WU@#042Q0T>D336!IH(VA:0$_P``,:T0WU@#T&L+WH
M\(>V]8`V9_$`![?Q_S\(OQ;U@#^XT4_P_S`!1M_G"$AX1/_W2O\'2'A$__=&
M__[W6N[N:0````$``*AJ``!&:0``\A8``-H6```(M4_T@%RMZPP,S/CX#_[W
M#.[^]_[M`+$`:`B]\+5/](!<K>L,#,SXT`\F2H>P)DL%1GI$)4X$J7Y$TU@P
M1AMH!9-/\``#__>A^!"Q`W@$1HNY'TH<2WI$TU@::`6;6D!/\``#+-$;2"E&
M>$0'L+WH\$#_]X^Y*$;^]W[N!T8@1O[W>NXX1`(P_O=2[A)+3_#_,@$A>T0!
MDQ!+`I0$1GM$`)7^]XCN#DH'2WI$TU@::`6;6D!/\``#!+\A1C!&U=#^]^SM
MLF@````!``"<%@``CF@``&H6``!0%0``2A4``#IH```MZ?!/3_2`7*WK#`S,
M^.`.W_@X%+^PW_@X5"2OW_@T)'E$?42"1@7Q#`,%\1@,*JPP-8I8)D8-\9P)
MW_@<M!)H/9)/\``"#?$@")/H!P"'Z`<`^T2\Z`\`#\:<Z`,`AN@#`)7H!P")
MZ`<`_$A!1GA$__<:^""Q`W@%1@`K0/!I@?[W8.W^]U+M`"@`\)V`!F@`+@#P
MF8`P1O[W_.U```$P_O?4[3%X!48'D'FQW_BPD_E$*$8`D4M&`2%/\/\R`C7^
M]P;N%O@!'P`I\M'E2'A$`N!4^`0/B+%!1O[WY?\%1@`H]M`#>``K\]#_]RGX
M`"COT"A&_O=:[01&B+E7^`1+=+$C>``K`/`/@2!&__<8^``H\]`@1O[W2NT$
M1@`H[=`@1O[WN.T'G09&*$;^][+M!D0&\@1&,$;^]XCMRDL'1D_P_S)[1`*3
MR$L!(0.5>T0!D\=+`)1[1/[WNNU/].!Q.$;^]\KM`3`%T?[WK.T!:!$I0/#@
M@$%&.$;^]_KM!48`*#G0NTG:^``PNTI;^`$`>D0`EP$A`&C^]\SM`":W2JQ+
M>D336!IH/9M:0$_P``-`\$:!,$8_L+WH\(_^]_;L!D8`*$#PLH!9^`0+6+%!
M1O[W:O\`*/?0`W@`*^[16?@$"P`H\]&F3@T@_O<P[5,A!49^1`>06><,FP/T
M<$.S]8!/O]$.G/[WGNR$0KK1#)O#\P@#L_7@?[31,$;^]Q;M!D:82$%&>$3^
M]S[_`48`*`#PH8#:^```__<F^H%&`"@`\)F`2$;^]R;M!$8#*`_9C4D$.$A$
M>43^]USL0+D$+`#PV8!,1!3X!3PO*P#PTX"&2$%&>$3^]Q?_(+$#>#`K&+\`
M*P;1`"%(1O[WVNP$1@`H<]%^27](>43?^/RA>$3?^/B1__<$^-_X]('^]^;L
M?$M/\/\R`2%[1`.3>DOZ1`"7^41[1,WI`3!X2S!&^$1[1/[W_NP3X/[W].P#
M:!$K%M'^]\SL`36$1E-&(D8!(3!&S>D#6<WI`8P`E_[WZ.Q/].!Q,$;^]_CL
M!$9#'./0.$;^]R;L9D@Q1GA$_O?(_S!&__<)_CKG'$;YYO[WLNQ```$PM.9/
M2MKX`#!;^`(`S>D`<0$A6TH`:'I$_O?R["3G__?Q_5A*/DMZ1--8&F@]FUI`
M3_```VK1*$8_L+WH\$_^]QF\VO@`D&/G__<P_8!&L?$`"87;L/$*`D_P``II
M\0`#($8-\<`+S?@`H/[W/NP&(EE&($;^]\;K!BA)T3":3_2&0\3R03.:0G_T
M:J^[^`0@1/)(4YI"?_1CK[CQ,@(@1FGQ``,RK<WX`*#^]Q[L($8H(BE&_O>F
MZR@H*=$R2P$A,DHP1GM$`9,Q2WI$`I4#DGM$3_#_,@"7C?CPH/[W7NQ\Y]KX
M!$``+#_T**\@1O[W..P#*'_V(J\F200X($1Y1/[W;NL`*`B_H487Y_[WNNLA
M2'A$__>@_.!G```6:0````$``*YG``!V%```6!4``-(4``#8%```OA,``+H4
M```0`0``T!0``%YF```.%```CA0``&84``#@$@``.!,``+82```Z%```WA0`
M`#X2``#H%```2!(``!@4``#*$0``VA(``*9D```4$0``HA,``-02``"2$@``
MAA(``'"U3_2`7*WK#`S,^.@/9$F"L&1*'>YP3WE$64MB2&Y&BEAX1#%&$F@!
MDD_P``)[1!MHY5B5^&@PA?AI,/[WS/T0L0-X,2M\T/_W+OI-2WM$&VCE6%5)
M*$8#(P$B>43^]YKK!49PL0)I1TM[1!MH$6A/2N!8>D3^]UCK*VD9:(MH6P)K
MU$%)`R,!(GE$"6A@6$A)>43^]W[K!49XL49(,49X1/[WF?T"1@`H3M`X2REI
M>T0;:`EHX%C^]S;K-4L!(CY)>T0;:'E$Y5@H1O[WC.L[2@%&*$9Z1#I-_O<F
MZRY+.4A]1'M$&V@`(GA$,4;C6(/X:2#^]W#]!$:H8+"Q3_3@<2!&_O>0ZT(<
M`T81*!B_`2HLV"U*(TMZ1--8&F@!FUI`3_```R#1`K!PO6AH__?__`1&J&``
M*.'1)4AX1/[W9NM#>``KA=!^YR)+*FE[1!!H6V@9:/[W!_^OYP]+>T0;:.!8
M_O=RZXSG_O>^ZAI)(D8:2'E$>$1):`EH_O=&ZPYD``#N8P``TF,``+)C``",
M8P``>F,``%AC``#>8@``&&,````!``!&$```X!$``,P1``"V$0``@`\``(81
M``".$0``RF,``"H/```88@``,!$``%YC```X8P``&A$``#"U3_2`7*WK#`S,
M^.@/*4H$1BE+@[!Z1"A(:49X1--8&V@!DT_P``/^]^;\<+$#>``K&+\P*PR_
M`2,`(X/P`0,`+`R_`",#\`$#6[D<2AI+>D336!IH`9M:0$_P``,GT0.P,+TC
M>``K\-`@1O_WGO@O(05&_O<JZP"Q11PH1O[W/NH0200B>43^]SCK`"C=T0U*
M"4MZ1--8&F@!FUI`3_```P71($8#L+WH,$#^]RR]_O<JZCIA`````0``B`X`
M``!A``#F#@``O&```"WI\$]/](!<K>L,#,SX,`W?^!!*K?4K?0-&"*D#\8`'
MW_@$.GQ$`I`*1D`P`":\1N-8&VBIDT_P``-0Z0)T5F#68!`R/[I"^!!\(PHE
M`@/T?T,(,$/J%&,%]'\%0^H$8V!%0^H%`T+X"#SFT=WI(H(*K":;#?&("0"3
M)*@FK0'U`G,#D"!&!)7-Z05!#6C-^!R0D4;=^)3@W?B<P`F?W?@LL"2>W?@H
MH`"9`9,!X))&FT8`D0`CT.D.%%#X""]#9U%`@>H(`;!&0VAI0`">549<0(3J
M"03Q1GQ`YD9/ZM%\21A,ZD0,`9Q!Z@P!7T9/\``,A$(!9]K1`YL"F-WI!4$=
M:`2;T.D!>QMH`Y/0Z0,Z3^J;#M#X`,`*:"%H3NJ#?H1I1_:9$\7V@B,`E`1J
MTAA/ZMQ@`91`ZD<0$AD`G$#J3!#=^!R0@AB*Z@0`3NJ+?@#J"P#=^#"`8$#9
M^`!@$AA/ZIP)BNH.`,D82>J'>0#J#`!)ZHQY"1F`Z@H`#I\(&([J"0$8ZP,(
M$4``Z_)@&.L*"('J#@%/ZK("&.L!`?\8%^L."`'K\&>)Z@(!W?A`X`%`3^JP
M`('J"0$8ZP$!'NL##A[K"0D!Z_=N@NH``=WX2(`Y0$_JMP=10!GK`0$8ZP,(
M&.L""8#J!P+=^%"``NH.`@'K_F%"0$_JO@X9ZP("&.L#"!CK``D"Z_%@A^H.
M`MWX6(`*0$_JL0%Z0!GK`@(8ZP,(&.L'"0+K\&>.Z@$"W?A@@`)`3^JP`(+J
M#@(9ZP("&.L#"!CK#@D"Z_=N@>H``MWX:(`Z0$_JMP=*0!GK`@(8ZP,(&.L!
M"0+K_F&`Z@<"W?AP@`+J#@)/ZKX.0D`9ZP("&.L#"!CK``D"Z_%@A^H.`MWX
M>(`*0$_JL0%Z0!GK`@(8ZP,(&.L'"0+K\&>.Z@$"W?B`@`)`3^JP`(+J#@(#
MG!GK`@(8ZP,(&.L.#@+K]VB!Z@`".D!/ZK<'2D`>ZP("]AAV&(#J!P$!Z@@!
M`NOX8D%`3^JX"'$8[1@M&`'K\F"'Z@@!$4!/ZK("B.H"!GE`:1@&0"B=Y!@!
MZ_!AANH(!D_JL`#D&:09@NH`!^T8#T`5ZP@&*IT$Z_%D5T!/ZK$!]AF`Z@$.
M[1BO&`[J!`XLG4_JM`*.Z@`.!NOT9A?K#@2!Z@('[1@W0"T8+IA/0`3K]F3O
M&4_JM@;#&#"=6QB"Z@8!(4`'Z_1N44!/ZK0$6!A.]J$SQO;98S*9%>L#"`#K
M_F`8ZP((ANH$`H+J#@)/ZKX%&.L""(3J!0[*&#2?".OP88[J``Z2&4_JL``2
MZPX"-I[_&(7J``X"Z_%BCNH!#CP93^JQ`13K#@0XG_88@.H!#@3K\F2.Z@(.
M=1E/ZK("%>L.!3J>@>H"#O\8CNH$#C\8!>OT8!?K#@=/ZK0$%NL##CR='NL!
M#@?K\&&"Z@0'1T!/ZK``'NL'#N\8/IZ_&`[K\6*$Z@`.CNH!#D_JL0$7ZPX'
M%NL##D"='NL$#@?K\F2`Z@$'5T!/ZK("'NL'#N\80IX_&`[K]&"!Z@(.CNH$
M#D_JM`07ZPX'1)V"Z@0.]A@'Z_!GCNH`#G883^JP`!;K#@9&F83J``[M&`;K
M]V:.Z@<.K1A/ZK<'%>L.!4B:R1B`Z@<.!>OV98[J!@X,&4_JM@84ZPX$2IG2
M&(?J!@X$Z_5DCNH%#A`83^JU!1#K#@!,FH;J!0[)&`#K]&".Z@0.R1E/ZK0$
M$>L.`4Z?A>H$#M(8`>OP88[J``Z2&4_JL``2ZPX"4)[_&(3J``X"Z_%BCNH!
M#GT93^JQ`17K#@52G_88@.H!#H[J`@XT&13K#@0%Z_)F%^L##D_JL@)4G1[K
M``Z!Z@(`!.OV9'!`'NL`#D_JM@#M&(+J``9I&%:=9D`.Z_1NB1E/ZK0$ZQA8
MG9L8@.H$`H+J#@)/ZKX'FAA+]MQ#R/8;<P'K_F'M&$3J!PY:GB@8#NH!#@3J
M!P5.Z@4.`NOQ8A#K#@Y/ZK$!\!A<G0`91^H!!`[K\F840`?J`0Y/ZK("1.H.
M!`'J`@@D&.T80>H"`!7K!PXP0`3K]F5>G$#J"`!/ZK8&$.L.#N`8#NOU9$`8
M0NH&`0+J!@XI0&"?0>H.`4_JM04)&`'K]&#_&$;J!0$&Z@4.NA@A0&*?3^JT
M!$'J#@$%Z@0(B1C_&$7J!`(7ZP8.`D!DGP'K\&%"Z@@"3^JP`!+K#@+_&`3J
M``Y]&0+K\6=$Z@`"9IX*0$_JL0%"Z@X"W?B@X549\A@2&4#J`01/ZK<&!>OW
M93Q``.H!!SQ#0>H&!Z(8'NL#!"08`>H&#FJ8+T`"Z_5B1^H.!T_JM04\&4;J
M!0?`&`3K\F0&Z@4.0!@70$_JL@%LFD?J#@<_&$7J`0#2&"!`DAD'Z_1F!>H!
M!T_JM`0X0T'J!`>`&&Z:`>H$#C=`TA@`Z_9@51EPFD?J#@=/ZK8&?QG2&%48
M!^OP843J!@<$Z@8.<IH'0$?J#@=/ZK``?1G2&!(91NH`!`;J``<,0#Q#!>OQ
M9:08=)I/ZK$!!.OU9-(80.H!!P#J`0Z6&2]`=II'Z@X'3^JU!;\9TA@6&`?K
M]&!!Z@4'`>H%#GB:)T!'Z@X'3^JT!+\91>H$!M(8!D!2&`?K\&$%Z@0'3^JP
M`#Y#`I^V&``B!.H`#@;K\69Z8/I@>IK2&%49`")Z8?IA1.H`!WR:#T!'Z@X'
M3^JQ`7\9TAA`Z@$%!^OV9Q+K!`XU0$_JM@1^F@#J`08U0P'J!`85ZPX%TQ@;
M&$'J!``X0(":,$,%Z_=EP!A,\M83S/9B(T_JMP?6&(*:=AB$Z@<!:4``Z_5@
M=AA/ZK4%TAB'Z@4!%!F$FD%`!NOP9F083^JP`-(8A>H``=<9AIH$Z_9D<4!_
M&$_JM@;1&(B:21D'Z_1E@.H&!V=`3^JT!,D9UQ@_&(J:ANH$``'K]6%H0$_J
MM04_&-`8@!F,F@?K\6:$Z@4'3T!/ZK$!P!G7&#\9CIJ%Z@$$`.OV8'1`/QE/
MZK8$UAB0FG89!^OP98'J!`='0$_JL`#V&=<8?QB2F@;K]6&$Z@`&;D!/ZK4%
MOQG6&#89E)H'Z_%D@.H%!T]`3^JQ`?89UQ@_&)::!NOT8(7J`09F0$_JM`2_
M&=88=AF8F@?K\&6!Z@0'1T!/ZK``]AG7&'\8FIH&Z_5AA.H`!FY`3^JU!;\9
MUA@V&9R:!^OQ9(#J!0=/0$_JL0'V&=<8/QB>F@;K]&"%Z@$&9D!/ZK0$OQG6
M&'89H)H'Z_!E@>H$!T=`3^JP`/89TAA7&`;K]6&BFH3J``9N0$_JM06_&=(8
M%AD'Z_%D@.H%!Z2:3T!/ZK$!]QD"G@?K]&?2&!`8"NNW`C)AIIJ%Z@$&9D!/
MZK0$@!G3&('J!`(`Z_=@>D`3ZPP#`I];&9L8$.L+`@/K\&,`F#M@`9LD&+I@
M#$K)&``C>V()2WI$O&$Y8M-8&FBIFUI`3_```P/1#?4K?;WH\(_]]P[M`+]@
M8`````$``()6```(M4_T@%RMZPP,S/CX#X`@_?=&[9_M#GL`(H)G@.T`>Y_M
M#7N`[0)[G^T->X#M!'N?[0U[@.T&>Y_M#7N`[0A[G^T->X#M"GN`[0Q["+T`
MOP$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````````
M`````"WI^$-/](!<K>L,#,SXX`\%1H!J%D8`(PQ&`.O&#/<7A$7H:M7I#"%S
MZP```M(!,D'Q``&H;P7Q.`C%Z0K#<P]#ZL<#FQ@K8T'K5W%I8X"[/RY%W:;Q
M0`E/ZID6=QP$ZX<7(49#1@3Q0`[1^`#`$#%1^`Q,$#-1^`@,4?@$+'%%0_@0
MS$/X#$Q#^`@,0_@$+.O1#$8H1O_W6_J\0N'1J>N&%C)&.49`1OWW2NRN9[WH
M^(/`\4`'!?$X"+="0$2HOS=&(48Z1OWW/.RK;SM$JV=`*^S1*$;V&SQ$__<Y
M^K?G)T;>YRWI\$%/](!<K>L,#,SXZ`^+:@'Q.`<*:PQ&D_J#^`5&P_/%`Q:Z
M61R`(C@I^E1%W<'Q0`)X&``A_??<["!&__<5^CA&."(`(?WWU.P@1L3I'&C_
M]POZXW@K<"!&8XAK<"-H&PJK<"-HZW#C>BMQ8XEK<:-H&PJK<:-HZW'C?"MR
M8XIK<B-I&PJK<B-IZW+C?BMS8XMK<Z-I&PJK<Z-IZW.4^",P*W1CC&MT(VH;
M"JMT(VKK=+WH\$']]\B[>!C!\3@"`"']]Y;LP.<`OP)+>T0;:/WW[[L`OU95
M```(0"WI"("]Z`$``@`^````00````P```!!````$0```$$````G````00``
M`#8```!!`````P```$$````&````00```!4```!!````#P```$$````.````
M00```"8```!!````$P```$$````I````00````(```!!````&0```$$````*
M````00````L```!!```````````````E<R\E<P```"]P<F]C+W-E;&8O97AE
M``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z
M.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?
M4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,
M24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%2
M7T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$
M25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````#$```!L
M<V5E:R!F86EL960`````<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%-9
M4U1%30``)3`R>``````E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!
M5$@`````<&%R;``````N<&%R`````'-H;W)T(')E860``"5S)7-C86-H92TE
M<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8````
M<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-C,```!5
M;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T523D%-10````!414U0
M1$E2`%1-4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%
M7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%2
M7TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[
M("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?
M34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*
M;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I
M("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S
M(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@
M,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N
M:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN
M9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@
M)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@
M*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE
M*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z
M.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ
M4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P
M87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M
M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*
M:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T
M;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&
M25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@
M)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@
M)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE
M;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ
M<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N
M=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V
M86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$
M14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-
M4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>
M*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@
M("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI
M.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O
M9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?
M5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?
M7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L
M("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D
M<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I
M<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I
M;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T
M<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@
M9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD
M(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP
M0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I
M.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I
M('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,[
M"GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@
M7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N
M<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&
M24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S
M96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(
M+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T
M:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D
M(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&
M24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]
M?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S
M96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\
M*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH
M(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L
M94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R
M8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H
M<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F
M("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE
M>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I
M<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I
M;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F
M:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^
M<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D[
M"B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M
M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D
M4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,
M12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`[
M"GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@
M("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B
M=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?
M05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I
M='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W
M*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A
M;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*
M)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C
M(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@
M*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N
M*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN
M8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]
M"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]
M"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E
M<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G
M*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q
M=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@
M(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@
M)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*
M?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@
M>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER
M92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!
M4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET
M.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T
M*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@
M)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B
M)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D
M9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q
M<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE
M=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC
M;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*
M9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@
M97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T
M*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/
M7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B
M)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N
M.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X[
M"GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D[
M"GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I
M<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R
M97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O
M<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N
M92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\
M+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD
M7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU
M97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET
M=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K
M97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A
M9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O
M)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S
M*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@
M/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I
M;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N
M="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6
M>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O
M:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O
M;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A
M8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z
M("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D
M>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R
M="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^
M<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H
M95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K
M("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@
M,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4[
M"B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE
M;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<
M,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D
M;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?
M34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R
M86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70[
M"GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O
M9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@
M("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A
M;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R
M96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H
M92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U
M=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO
M72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB
M97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D
M;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S
M=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB
M97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R
M('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF
M("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H
M97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G
M93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@
M<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F
M:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H
M)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S
M96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R
M<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR
M97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G
M97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E
M('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE
M.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@
M4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O
M;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D
M('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C
M86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ
M0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U
M<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P
M87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R
M;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!
M4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<
M5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A
M;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P
M=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE
M9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD
M=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E
M<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-4
M14TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N
M=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H
M95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H
M)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F
M9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E
M860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I
M>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F
M(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC
M;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B
M=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@
M(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U
M-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E
M;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D
M;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]
M("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@
M)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E
M("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A
M73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E
M;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M
M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*
M:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@
M)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI
M="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF
M(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]4
M14U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL
M(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?
M97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES
M>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$
M?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!
M3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"
M54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)]
M.PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.
M5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI
M('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T
M=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?
M7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@
M>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE
M<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS
M:2YC`````$-!0TA%```^````00````P```!!````$0```$$````G````00``
M`#8```!!`````P```$$````&````00```!4```!!````#P```$$````.````
M00```"8```!!````$P```$$````I````00````(```!!````&0```$$````*
M````00````L```!!``````````````#`F?]_`0``````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````!Q%P``,1<```$````C`P```0```#,#```!````
M/0,```P```"H$0``#0```+@Z```9````P(T``!L````$````&@```,2-```<
M````!````/7^_V^T`0``!0```"`)```&````H`(```H```"X!```"P```!``
M```5``````````,```#0C@```@```-@!```4````$0```!<```#0#P``$0``
M`/@.```2````V````!,````(````'@````@```#[__]O`0``"/[__V^H#@``
M____;P(```#P__]OV`T``/K__V\.````````````````````````````````
M`````````````````````````,B-`````````````+01``"T$0``M!$``+01
M``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$`
M`+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``
MM!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T
M$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01
M``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``M!$``+01``"T$0``````
M`````````````````````````````````````````````````*$4````````
M````````````````!)````I005(N<&T*`````)P^``"P.P```````'`\``!T
M/```D#X``+@[``"8/@```````'P^``"$/@```````*0^``!'0T,Z("A$96)I
M86X@,3,N,BXP+3$Y*2`Q,RXR+C``03(```!A96%B:0`!*`````4W+4$`!@H'
M00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%2
M32YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y
M;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E
M<P````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``&0```````````````0`````````3````!P``
M``(```!P`0``<`$``"0```````````````0`````````)@````<````"````
ME`$``)0!```@```````````````$`````````#0```#V__]O`@```+0!``"T
M`0``[`````4`````````!`````0````^````"P````(```"@`@``H`(``(`&
M```&`````P````0````0````1@````,````"````(`D``"`)``"X!```````
M```````!`````````$X```#___]O`@```-@-``#8#0``T`````4`````````
M`@````(```!;````_O__;P(```"H#@``J`X``%`````&`````@````0`````
M````:@````D````"````^`X``/@.``#8````!0`````````$````"````',`
M```)````0@```-`/``#0#P``V`$```4````5````!`````@```!\`````0``
M``8```"H$0``J!$```P```````````````0`````````=P````$````&````
MM!$``+01``#H`@`````````````$````!````((````!````!@```*`4``"@
M%```&"8`````````````"`````````"(`````0````8```"X.@``N#H```@`
M``````````````0`````````C@````$````"````P#H``,`Z``#X00``````
M```````$`````````)8````!``!P@@```+A\``"X?```"`````T`````````
M!`````````"A`````0````(```#`?```P'P```0```````````````0`````
M````JP````X````#````P(T``,!]```$```````````````$````!````+<`
M```/`````P```,2-``#$?0``!```````````````!`````0```##````!@``
M``,```#(C0``R'T```@!```&``````````0````(````S`````$````#````
MT(X``-!^```P`0`````````````$````!````-$````!`````P````"0````
M@```2```````````````!`````````#7````"`````,```!(D```2(```!0`
M``````````````0`````````W`````$````P`````````$B````?````````
M```````!`````0```.4````#``!P``````````!G@```,P``````````````
M`0`````````!`````P``````````````FH```/4```````````````$`````
#````
